@@ -48,4 +48,12 @@ def removalEffect(dm, dfSi, dfSij):
     removal_effect_Ei = []
     for i in range(0,len(dm.columns)):
         removal_effect_Ei.append(abs(dfSij.iloc[:,i]-list(dfSi)).sum())
-    return sum(removal_effect_Ei)
\ No newline at end of file
+    return removal_effect_Ei
+
+##################################################
+######### Nihai ağırlıkların hesaplanması ########
+##################################################
+def calculatingWeight(liste, dm):
+    df_weight = pd.DataFrame(columns = list(dm.columns))
+    df_weight.loc[0] = list(liste/sum(liste))
+    return df_weight
\ No newline at end of file
